@@ -16,27 +16,32 @@ from distutils.version import StrictVersion as V
 from pipes import quote
 import os
 import posixpath
+import re
 
 from fabric.api import cd, hide, prefix, run, settings, sudo
 from fabric.utils import puts
 
+from fabtools.files import is_file
 from fabtools.utils import abspath, run_as_root
 
 
-def is_pip_installed(version=None, use_python='python'):
+def is_pip_installed(version=None, pip_cmd='pip'):
     """
     Check if `pip`_ is installed.
 
     .. _pip: http://www.pip-installer.org/
     """
     with settings(hide('running', 'warnings', 'stderr', 'stdout'), warn_only=True):
-        res = run('%(use_python)s -m pip --version 2>/dev/null' % locals())
+        res = run('%(pip_cmd)s --version 2>/dev/null' % locals())
         if res.failed:
             return False
         if version is None:
             return res.succeeded
         else:
-            installed = res.split(' ')[1]
+            m = re.search(r'pip (?P<version>.*) from', res)
+            if m is None:
+                return False
+            installed = m.group('version')
             if V(installed) < V(version):
                 puts("pip %s found (version >= %s required)" % (installed, version))
                 return False
@@ -44,11 +49,10 @@ def is_pip_installed(version=None, use_python='python'):
                 return True
 
 
-def install_pip(use_python='python'):
+def install_pip(python_cmd='python', use_sudo=True):
     """
-    Install the latest version of `pip`_.
-
-    .. _pip: http://www.pip-installer.org/
+    Install the latest version of `pip`_, using the given Python
+    interpreter.
 
     ::
 
@@ -57,34 +61,54 @@ def install_pip(use_python='python'):
         if not fabtools.python.is_pip_installed():
             fabtools.python.install_pip()
 
+    .. note::
+        pip is automatically installed inside a virtualenv, so there
+        is no need to install it yourself in this case.
+
+    .. _pip: http://www.pip-installer.org/
     """
+
     with cd('/tmp'):
+
         run('curl --silent -O https://raw.github.com/pypa/pip/master/contrib/get-pip.py')
-        run_as_root('%(use_python)s get-pip.py' % locals(), pty=False)
 
+        command = '%(python_cmd)s get-pip.py' % locals()
+        if use_sudo:
+            run_as_root(command, pty=False)
+        else:
+            run(command, pty=False)
 
-def is_installed(package, use_python='python'):
+        run('rm -f get-pip.py')
+
+def is_installed(package, pip_cmd='pip'):
     """
-    Check if a Python package is installed.
+    Check if a Python package is installed (using pip).
+
+    Package names are case insensitive.
+
+    Example::
+
+        from fabtools.python import virtualenv
+        import fabtools
+
+        with virtualenv('/path/to/venv'):
+            fabtools.python.install('Flask')
+            assert fabtools.python.is_installed('flask')
+
+    .. _pip: http://www.pip-installer.org/
     """
-    options = []
-    options = ' '.join(options)
     with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
-        res = run('%(use_python)s -m pip freeze %(options)s' % locals())
-    packages = [line.split('==')[0] for line in res.splitlines()]
-    return (package in packages)
-
-
-def _get_python_version(use_python):
-    return run("""python -c 'import sys; print(".".join(map(str, sys.version_info[0:3])))'""").strip()
+        res = run('%(pip_cmd)s freeze' % locals())
+    packages = [line.split('==')[0].lower() for line in res.splitlines()]
+    return (package.lower() in packages)
 
 
 def install(packages, upgrade=False, use_mirrors=False, use_sudo=False,
-            user=None, download_cache=None, quiet=False, use_python='python'):
+            user=None, download_cache=None, quiet=False, pip_cmd='pip'):
     """
     Install Python package(s) using `pip`_.
 
-    .. _pip: http://www.pip-installer.org/
+    Package names are case insensitive.
 
     Examples::
 
@@ -96,9 +120,11 @@ def install(packages, upgrade=False, use_mirrors=False, use_sudo=False,
         # Install a list of packages
         fabtools.python.install(['pkg1', 'pkg2'], use_sudo=True)
 
+    .. _pip: http://www.pip-installer.org/
     """
     if not isinstance(packages, basestring):
         packages = ' '.join(packages)
+
     options = []
     if use_mirrors:
         options.append('--use-mirrors')
@@ -110,14 +136,7 @@ def install(packages, upgrade=False, use_mirrors=False, use_sudo=False,
         options.append('--quiet')
     options = ' '.join(options)
 
-    version = _get_python_version(use_python).split('.')
-
-    if (int(version[0]) < 3) and (int(version[1]) < 7):
-        command = 'pip-%s.%s' % (version[0], version[1])
-    else:
-        command = '%(use_python)s -m pip' % locals()
-
-    command += ' install %(options)s %(packages)s' % locals()
+    command = '%(pip_cmd)s install %(options)s %(packages)s' % locals()
 
     if use_sudo:
         sudo(command, user=user, pty=False)
@@ -127,7 +146,7 @@ def install(packages, upgrade=False, use_mirrors=False, use_sudo=False,
 
 def install_requirements(filename, upgrade=False, use_mirrors=False,
                          use_sudo=False, user=None, download_cache=None,
-                         quiet=False, use_python='python'):
+                         quiet=False, pip_cmd='pip'):
     """
     Install Python packages from a pip `requirements file`_.
 
@@ -149,13 +168,58 @@ def install_requirements(filename, upgrade=False, use_mirrors=False,
     if quiet:
         options.append('--quiet')
     options = ' '.join(options)
-    command = '%(use_python)s -m pip install %(options)s -r %(filename)s' % locals()
+
+    command = '%(pip_cmd)s install %(options)s -r %(filename)s' % locals()
+
     if use_sudo:
         sudo(command, user=user, pty=False)
     else:
         run(command, pty=False)
 
 
+def create_virtualenv(directory, system_site_packages=False, venv_python=None,
+               use_sudo=False, user=None, clear=False, prompt=None,
+               virtualenv_cmd='virtualenv'):
+    """
+    Create a Python `virtual environment`_.
+
+    ::
+
+        import fabtools
+
+        fabtools.python.create_virtualenv('/path/to/venv')
+
+    .. _virtual environment: http://www.virtualenv.org/
+    """
+    options = ['--quiet']
+    if system_site_packages:
+        options.append('--system-site-packages')
+    if venv_python:
+        options.append('--python=%s' % quote(venv_python))
+    if clear:
+        options.append('--clear')
+    if prompt:
+        options.append('--prompt=%s' % quote(prompt))
+    options = ' '.join(options)
+
+    directory = quote(directory)
+
+    command = '%(virtualenv_cmd)s %(options)s %(directory)s' % locals()
+    if use_sudo:
+        sudo(command, user=user)
+    else:
+        run(command)
+
+
+def virtualenv_exists(directory):
+    """
+    Check if a Python `virtual environment`_ exists.
+
+    .. _virtual environment: http://www.virtualenv.org/
+    """
+    return is_file(posixpath.join(directory, 'bin', 'python'))
+
+
 @contextmanager
 def virtualenv(directory, local=False):
     """
