@@ -17,7 +17,7 @@ from fabtools.utils import run_as_root
 import fabtools.supervisor
 
 
-VERSION = '2.6.14'
+VERSION = '2.6.16'
 
 BINARIES = [
     'redis-benchmark',
@@ -66,7 +66,7 @@ def installed_from_source(version=VERSION):
 
             # Download and unpack the tarball
             tarball = 'redis-%(version)s.tar.gz' % locals()
-            url = 'http://redis.googlecode.com/files/' + tarball
+            url = _download_url(version) + tarball
             require_file(tarball, url=url)
             run('tar xzf %(tarball)s' % locals())
 
@@ -79,10 +79,67 @@ def installed_from_source(version=VERSION):
                     run_as_root('chown redis: %(dest_dir)s/%(filename)s' % locals())
 
 
-def instance(name, version=VERSION, **kwargs):
+def _download_url(version):
+    if _parse_version(version) <= (2, 6, 14):
+        return 'http://redis.googlecode.com/files/'
+    else:
+        return 'http://download.redis.io/releases/'
+
+
+def _parse_version(version):
+    return tuple(map(int, version.split('.')))
+
+
+def instance(name, version=VERSION, bind='127.0.0.1', port=6379, **kwargs):
     """
     Require a Redis instance to be running.
 
+    The required Redis version will be automatically installed using
+    :py:func:`fabtools.require.redis.installed_from_source` if needed.
+
+    You can specify the IP address and port on which to listen to using the
+    *bind* and *port* parameters.
+
+    .. warning::
+        Redis is designed to be accessed by trusted clients inside trusted
+        environments. It is usually not a good idea to expose the Redis
+        instance directly to the internet. Therefore, with the default
+        settings, the Redis instance will only listen to local clients.
+
+    If you want to make your Redis instance accessible to other servers
+    over an untrusted network, you should probably add some firewall rules
+    to restrict access. For example: ::
+
+            from fabtools import require
+            from fabtools.shorewall import Ping, SSH, hosts, rule
+
+            # The computers that will need to talk to the Redis server
+            REDIS_CLIENTS = [
+                'web1.example.com',
+                'web2.example.com',
+            ]
+
+            # The Redis server port
+            REDIS_PORT = 6379
+
+            # Setup a basic firewall
+            require.shorewall.firewall(
+                rules=[
+                    Ping(),
+                    SSH(),
+                    rule(port=REDIS_PORT, source=hosts(REDIS_CLIENTS)),
+                ]
+            )
+
+            # Make the Redis instance listen on all interfaces
+            require.redis.instance('mydb', bind='0.0.0.0', port=REDIS_PORT)
+
+    .. seealso:: `Redis Security <http://redis.io/topics/security>`_
+
+    You can also use any valid Redis configuration directives as extra
+    keyword arguments. For directives that can be repeated on multiple
+    lines (such as ``save``), you can supply a list of values.
+
     The instance will be managed using supervisord, as a process named
     ``redis_{name}``, running as the ``redis`` user.
 
@@ -91,17 +148,25 @@ def instance(name, version=VERSION, **kwargs):
         from fabtools import require
         from fabtools.supervisor import process_status
 
-        require.redis.installed_from_source()
+        require.redis.instance('mydb')
 
-        require.redis.instance('db1', port='6379')
-        require.redis.instance('db2', port='6380')
-
-        print process_status('redis_db1')
-        print process_status('redis_db2')
+        print process_status('redis_mydb')
 
     .. seealso:: :ref:`supervisor_module` and
                  :ref:`require_supervisor_module`
 
+    The default settings enable persistence using periodic RDB snapshots
+    saved in the `/var/db/redis` directory.
+
+    You may want to use AOF persistence instead: ::
+
+        require.redis.instance('mydb', appendonly='yes', save=[])
+
+    In certain situations, you may want to disable persistence completely: ::
+
+        require.redis.instance('cache', port=6380, save=[])
+
+    .. seealso:: `Redis Persistence <http://redis.io/topics/persistence>`_
 
     """
     from fabtools.require import directory as require_directory
@@ -122,8 +187,8 @@ def instance(name, version=VERSION, **kwargs):
     # Set default parameters
     params = {}
     params.update(kwargs)
-    params.setdefault('bind', '127.0.0.1')
-    params.setdefault('port', '6379')
+    params.setdefault('bind', bind)
+    params.setdefault('port', port)
     params.setdefault('logfile', '/var/log/redis/redis-%(name)s.log' % locals())
     params.setdefault('loglevel', 'verbose')
     params.setdefault('dir', '/var/db/redis')
