@@ -12,6 +12,7 @@ from __future__ import with_statement
 
 from fabtools.files import watch
 from fabtools.supervisor import update_config, process_status, start_process
+from fabtools.system import distrib_family
 
 
 def process(name, **kwargs):
@@ -49,12 +50,19 @@ def process(name, **kwargs):
     .. _supervisor documentation: http://supervisord.org/configuration.html#program-x-section-values
     """
 
-    from fabtools.require.deb import package as require_package
     from fabtools.require import file as require_file
+    from fabtools.require.deb import package as require_deb_package
+    from fabtools.require.rpm import package as require_rpm_package
     from fabtools.require.service import started as require_started
 
-    require_package('supervisor')
-    require_started('supervisor')
+    family = distrib_family()
+
+    if family == 'debian':
+        require_deb_package('supervisor')
+        require_started('supervisor')
+    elif family == 'redhat':
+        require_rpm_package('supervisor')
+        require_started('supervisord')
 
     # Set default parameters
     params = {}
@@ -69,7 +77,10 @@ def process(name, **kwargs):
         lines.append("%s=%s" % (key, value))
 
     # Upload config file
-    filename = '/etc/supervisor/conf.d/%(name)s.conf' % locals()
+    if family == 'debian':
+        filename = '/etc/supervisor/conf.d/%(name)s.conf' % locals()
+    elif family == 'redhat':
+        filename = '/etc/supervisord.d/%(name)s.ini' % locals()
     with watch(filename, callback=update_config, use_sudo=True):
         require_file(filename, contents='\n'.join(lines), use_sudo=True)
 
