@@ -44,7 +44,7 @@ def start(service):
         if not fabtools.service.is_running('foo'):
             fabtools.service.start('foo')
     """
-    run_as_root('service %(service)s start' % locals())
+    run_as_root('service %(service)s start' % locals(), pty=False)
 
 
 def stop(service):
@@ -76,7 +76,7 @@ def restart(service):
         else:
             fabtools.service.start('foo')
     """
-    run_as_root('service %(service)s restart' % locals())
+    run_as_root('service %(service)s restart' % locals(), pty=False)
 
 
 def reload(service):
@@ -94,7 +94,7 @@ def reload(service):
 
         The service needs to support the ``reload`` operation.
     """
-    run_as_root('service %(service)s reload' % locals())
+    run_as_root('service %(service)s reload' % locals(), pty=False)
 
 
 def force_reload(service):
@@ -112,4 +112,4 @@ def force_reload(service):
 
         The service needs to support the ``force-reload`` operation.
     """
-    run_as_root('service %(service)s force-reload' % locals())
+    run_as_root('service %(service)s force-reload' % locals(), pty=False)
