@@ -3,6 +3,17 @@ from __future__ import with_statement
 from fabric.api import task
 
 
+@task
+def python_setuptools():
+    """
+    Test setuptools installation
+    """
+
+    from fabtools import require
+
+    require.python.setuptools()
+
+
 @task
 def python_virtualenv():
     """
